package de.akquinet.zalit.client;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.google.gwt.user.client.ui.Button;
import com.google.gwt.user.client.ui.FlexTable;
import com.google.gwt.user.client.ui.HTMLTable;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.Widget;

public class ProjectDateTable extends FlexTable {
  private final int _initialRows;

  public ProjectDateTable(final int initialRows) {
    _initialRows = initialRows;
    setBorderWidth(1);
    setCellSpacing(0);
    addStyleName("ProjectDateTable"); // Siehe css
  }

  public void init(final List<String> dates) {
    System.out.println("Init table " + dates);
    insertRow(0);
    getRowFormatter().addStyleName(0, "ProjectDateTable-Header"); // Siehe css

    final List<String> tableHeaders = getTableHeaders(dates);

    for (final String header : tableHeaders) {
      addColumn(header);
    }

    for (int row = 1; row < _initialRows + 1; row++) {
      setText(row, 0, "Projekt " + row);
      getCellFormatter().addStyleName(row, 0, "ProjectDateTable-Cell"); // Siehe css

      for (int column = 1; column < tableHeaders.size(); column++) {
        setWidget(row, column, new Button("feld"));

        getCellFormatter().addStyleName(row, column, "ProjectDateTable-Cell"); // Siehe css
      }
    }

    applyDataRowStyles();
  }

  private void addColumn(final Object columnHeading) {
    final Widget widget = createCellWidget(columnHeading);
    final int cell = getCellCount(0);

    widget.setWidth("100%");
    widget.addStyleName("ProjectDateTable-ColumnLabel");

    setWidget(0, cell, widget);

    getCellFormatter().addStyleName(0, cell, "ProjectDateTable-ColumnLabelCell");
  }

  private Widget createCellWidget(final Object cellObject) {
    if (cellObject instanceof Widget) {
      return (Widget) cellObject;
    } else {
      return new Label(cellObject.toString());
    }
  }

  private void applyDataRowStyles() {
    final HTMLTable.RowFormatter rf = getRowFormatter();

    for (int row = 1; row < getRowCount(); ++row) {
      if ((row % 2) != 0) {
        rf.addStyleName(row, "ProjectDateTable-OddRow");
      } else {
        rf.addStyleName(row, "ProjectDateTable-EvenRow");
      }
    }
  }

  private List<String> getTableHeaders(final List<String> dates) {
    final List<String> result = new ArrayList<String>();

    result.add("Projekt");
    result.addAll(dates);

    return result;
  }

  @SuppressWarnings("deprecation")
  public static String format(final Date date) {
    return fillup2Digits(date.getDate()) + "." + fillup2Digits(date.getMonth() + 1);
  }

  private static String fillup2Digits(final int date) {
    final String result = String.valueOf(date);
    return (result.length() < 2) ? "0" + result : result;
  }
}
